# importing modules
import sys as sys
import os 
import pandas as pd 
import matplotlib.pyplot as plt
# Getting the name of the directory where this file is present.
current = os.path.dirname(os.path.realpath(__file__))  # src
# Getting the parent directory name where the current directory is present.
parent = os.path.dirname(current) # Simulation
# Getting the grandparent directory name
gparent = os.path.dirname(parent) # RecruitmentSynchronization_SMCs
# The path where the plotExp.py is saved
mpath = gparent + '\\cellLib\\Scripts'
# appending a path
sys.path.append(mpath)
import plotExp
# The properties of traces
colors=plt.rcParams['axes.prop_cycle'].by_key()['color']
lines = ['-','--','-.',':']
markers = ['.',',','o','+','x','d']
# Figure file name and titles
figfiles=parent+'\\simFig11_908-comp.png'
fig_title = 'Primary Fig 11 with 908 entry'
plot_title =['','',]
labels = ['CellML Reference -40 mV','CellML Perchlorate -63 mV',]
# Data source
dfolder_original=parent+'\\originalData\\'
dfilenames_r=['simFig11_r.csv','simFig11_r.csv']
dfilenames_p=['simFig11_p.csv','simFig11_p.csv']
dfolder_sim=parent+'\\simulatedData\\'
x_vars_sim = ['t','t',]
y_vars_sim = ['output_10/P_o','output_10/dQ',]
x_label=['t (ms)','t (ms)',]
y_label=['Open probability','Charge current /ms']
Qmax=23.1
# Build the traces
number_trace = 2
number_plot = len(y_vars_sim)
trace = [[0] * number_trace for i in range(number_plot)]


for plotid, y_var_sim in enumerate(y_vars_sim):

   ndata = pd.read_csv(dfolder_sim+dfilenames_r[plotid])
   nx_data_r=ndata[x_vars_sim[plotid]].values-200 
   ny_data_r=ndata[y_vars_sim[plotid]].values     
   ndata = pd.read_csv(dfolder_sim+dfilenames_p[plotid])
   nx_data_p=ndata[x_vars_sim[plotid]].values-200 
   ny_data_p=ndata[y_vars_sim[plotid]].values

   if plotid==0:
      ny_data_r=ny_data_r/0.317549
      ny_data_p=ny_data_p/0.92084 
     
   trace[plotid][0]={'dataX': nx_data_r, 'dataY': ny_data_r, 'lname': labels[0], 'linestyle':lines[1], 'marker':markers[0], 'linecolor':colors[0],'y2':False}
   trace[plotid][1]={'dataX': nx_data_p, 'dataY': ny_data_p, 'lname': labels[1], 'linestyle':lines[0], 'marker':None, 'linecolor':colors[1],'y2':False}
   
        
# Build the plots 
# maxH=8.75 inches, width 2.63-7.5
rows,cols = 1,2
left = 0.125  # the left side of the subplots of the figure,0.125
right = 0.9   # the right side of the subplots of the figure,0.9
bottom = 0.1  # the bottom of the subplots of the figure, 0.1
top = 0.8     # the top of the subplots of the figure 0.9
wspace = 0.5  # the amount of width reserved for space between subplots,
              # expressed as a fraction of the average axis width, 0.2
hspace = 0.25  # the amount of height reserved for space between subplots,
              # expressed as a fraction of the average axis height, 0.2
lgdfont, labelfont =10, 10
width, height= cols*3.5, rows*3
figs ={ 'width':width, 'height': height, 'rows': rows, 'cols': cols,'left':left,'bottom':bottom,'right':right,'top':top,'wspace': wspace,'hspace': hspace,'fig_title':fig_title,'title_y':1}

plots=[]
for id in range(2):    
   colid = id%2
   rowid = id//2
   if id == 0:
      lgdshow = True
      bbox_to_anchor = (1.2,1.1)      
   else:
      lgdshow = False
      bbox_to_anchor = None
       
   iplot={'rowid':rowid, 'colid':colid, 'xlabel': x_label[id], 'ylabel':y_label[id], 'twiny':False,    'ylabel2':y_label[id],'labelcolor':colors[1],
            'lgdshow': lgdshow, 'lgdloc':'center', 'bbox_to_anchor':bbox_to_anchor,'lgdncol': 2, 'lgdfont':lgdfont, 'labelfont': labelfont,  
            'setxlim': True, 'xmin':0, 'xmax': 200, 'setylim': False,'ymin':0, 'ymax':1, 'grid': True,    'gridaxis': 'both', 'plot_title': plot_title[id],
            'traces':trace[id]
            }   
   plots.append(iplot)

ids = range(len(y_vars_sim))   
subfigs={ids: plots for ids, plots in zip(ids, plots)}
fig,axs=plotExp.plotExp(figs,subfigs,figfiles)




